# Changelog

## [0.2.2] - 2020-10-19

- Fix accidentally not including the last fix in 0.2.1

## [0.2.1] - 2020-10-19

- Fixes to allow for a Conda package on Windows

## [0.2.0] - 2020-10-10

- Update docs with instructions for saving mesh
- Add `rescale_positions` util

## [0.1.0] - 2020-10-05

- Initial release

## [0.0.1], [0.0.2] - 2020-10-03

- Test releases on PyPI to test auto-building wheels with cibuildwheel
